@@ -78,7 +78,7 @@ class LocalTemplateResolver(Uri.FtUriResolver):
                 return file(resource, 'rb')
             raise UriException(UriException.RESOURCE_ERROR,
                                uri=uri, loc=uri,
-                               msg="The file did not exist in '%s'" % templates)
+                               msg="The file did not exist in '%s'" % self.templates)
         elif uri.startswith('pkg:'):
             # format: package#path/to/file.xslt
             usage = 'usage: package_name#path/to/file'
@@ -111,6 +111,8 @@ class TemplateMiddleware(object):
 
         self.ns = unicode(app_conf.get('xsltemplate_namespace',
                                        'http://ionrock.org/ns/xsltemplate'))
+        if app_conf.get('use_index_xml'):
+            self.content = app_conf['use_index_xml']
         self.template_key = XTemplate
         self.params_key = XParams
         self.source_key = XSource
@@ -132,6 +134,8 @@ class TemplateMiddleware(object):
 
     def __call__(self, environ, start_response):
         source = ''.join(self.app(environ, self.start_response))
+        if not source and self.content:
+            source = self.content
         if environ.get(self.template_key):
             xslt = environ[self.template_key]
             params = environ.get(self.params_key, {})
@@ -141,7 +145,7 @@ class TemplateMiddleware(object):
             if k.lower() == 'content-length':
                 del self.headers[i]
         start_response(self.status, self.headers, self.exc_info)
-        return [source]    
+        return [source]
 
 
     def get_processor(self):
@@ -150,15 +154,21 @@ class TemplateMiddleware(object):
             for ext in self.extensions:
                 proc.registerExtensionFunction(*(ext))
         return proc
-            
+
     def get(self, fn):
         if fn.startswith('pkg://'):
             package, sep, path = fn[6:].partition('#')
             if pkg_resources.resource_exists(package, path):
                 return self.xslt_factory.fromString(pkg_resources.resource_string(package, path))
         path = Uri.OsPathToUri(os.path.join(self.tdir, fn))
-        return self.xslt_factory.fromUri(path)
-        
+        try:
+            xslt = self.xslt_factory.fromUri(path)
+        except UriException:
+            xslt = self.xslt_factory.fromString(
+                fn, Uri.OsPathToUri(os.path.abspath('.'))
+            )
+        return xslt
+
     def run(self, xml, xslt, params):
         proc = self.get_processor()
         xml = CreateInputSource(xml)
@@ -201,7 +211,7 @@ class IndexXMLMiddleware(object):
 
     def __call__(self, environ, start_response, exc_info=None):
         c = self.app(environ, self.start_response)
-        start_response(self.status, self.headers, self.exc_info)        
+        start_response(self.status, self.headers, self.exc_info)
         if c:
             return c
         return [self.content]
